@@ -125,6 +125,8 @@ def test_parse_abnormal_specifiers(project):
         "demo @ file:///${PROJECT_ROOT}/tests/fixtures/artifacts/demo-0.0.1.tar.gz",
         "demo @ file:///${PROJECT_ROOT}/tests/fixtures/projects/demo",
         "-e ./tests/fixtures/projects/demo",
+        "-e file:///${PROJECT_ROOT}/tests/fixtures/projects/demo#egg=demo",
+        "-e file:///${PROJECT_ROOT}/tests/fixtures/projects/demo-#-with-hash#egg=demo",
     ],
 )
 def test_expand_project_root_in_url(req_str, core):
